<?php
namespace Typo3\Issue78128\Tests\Unit\Domain\Model;

/**
 * Test case.
 *
 * @author Robert Jelinek 
 */
class TableATest extends \TYPO3\CMS\Core\Tests\UnitTestCase
{
    /**
     * @var \Typo3\Issue78128\Domain\Model\TableA
     */
    protected $subject = null;

    protected function setUp()
    {
        $this->subject = new \Typo3\Issue78128\Domain\Model\TableA();
    }

    protected function tearDown()
    {
        parent::tearDown();
    }

    /**
     * @test
     */
    public function getCReturnsInitialValueForTableC()
    {
        $newObjectStorage = new \TYPO3\CMS\Extbase\Persistence\ObjectStorage();
        self::assertEquals(
            $newObjectStorage,
            $this->subject->getC()
        );

    }

    /**
     * @test
     */
    public function setCForObjectStorageContainingTableCSetsC()
    {
        $c = new \Typo3\Issue78128\Domain\Model\TableC();
        $objectStorageHoldingExactlyOneC = new \TYPO3\CMS\Extbase\Persistence\ObjectStorage();
        $objectStorageHoldingExactlyOneC->attach($c);
        $this->subject->setC($objectStorageHoldingExactlyOneC);

        self::assertAttributeEquals(
            $objectStorageHoldingExactlyOneC,
            'c',
            $this->subject
        );

    }

    /**
     * @test
     */
    public function addCToObjectStorageHoldingC()
    {
        $c = new \Typo3\Issue78128\Domain\Model\TableC();
        $cObjectStorageMock = $this->getMock(\TYPO3\CMS\Extbase\Persistence\ObjectStorage::class, ['attach'], [], '', false);
        $cObjectStorageMock->expects(self::once())->method('attach')->with(self::equalTo($c));
        $this->inject($this->subject, 'c', $cObjectStorageMock);

        $this->subject->addC($c);
    }

    /**
     * @test
     */
    public function removeCFromObjectStorageHoldingC()
    {
        $c = new \Typo3\Issue78128\Domain\Model\TableC();
        $cObjectStorageMock = $this->getMock(\TYPO3\CMS\Extbase\Persistence\ObjectStorage::class, ['detach'], [], '', false);
        $cObjectStorageMock->expects(self::once())->method('detach')->with(self::equalTo($c));
        $this->inject($this->subject, 'c', $cObjectStorageMock);

        $this->subject->removeC($c);

    }

    /**
     * @test
     */
    public function getBReturnsInitialValueForTableB()
    {
        $newObjectStorage = new \TYPO3\CMS\Extbase\Persistence\ObjectStorage();
        self::assertEquals(
            $newObjectStorage,
            $this->subject->getB()
        );

    }

    /**
     * @test
     */
    public function setBForObjectStorageContainingTableBSetsB()
    {
        $b = new \Typo3\Issue78128\Domain\Model\TableB();
        $objectStorageHoldingExactlyOneB = new \TYPO3\CMS\Extbase\Persistence\ObjectStorage();
        $objectStorageHoldingExactlyOneB->attach($b);
        $this->subject->setB($objectStorageHoldingExactlyOneB);

        self::assertAttributeEquals(
            $objectStorageHoldingExactlyOneB,
            'b',
            $this->subject
        );

    }

    /**
     * @test
     */
    public function addBToObjectStorageHoldingB()
    {
        $b = new \Typo3\Issue78128\Domain\Model\TableB();
        $bObjectStorageMock = $this->getMock(\TYPO3\CMS\Extbase\Persistence\ObjectStorage::class, ['attach'], [], '', false);
        $bObjectStorageMock->expects(self::once())->method('attach')->with(self::equalTo($b));
        $this->inject($this->subject, 'b', $bObjectStorageMock);

        $this->subject->addB($b);
    }

    /**
     * @test
     */
    public function removeBFromObjectStorageHoldingB()
    {
        $b = new \Typo3\Issue78128\Domain\Model\TableB();
        $bObjectStorageMock = $this->getMock(\TYPO3\CMS\Extbase\Persistence\ObjectStorage::class, ['detach'], [], '', false);
        $bObjectStorageMock->expects(self::once())->method('detach')->with(self::equalTo($b));
        $this->inject($this->subject, 'b', $bObjectStorageMock);

        $this->subject->removeB($b);

    }
}
