<?php
namespace Typo3\Issue78128\Tests\Unit\Domain\Model;

/**
 * Test case.
 *
 * @author Robert Jelinek 
 */
class TableBTest extends \TYPO3\CMS\Core\Tests\UnitTestCase
{
    /**
     * @var \Typo3\Issue78128\Domain\Model\TableB
     */
    protected $subject = null;

    protected function setUp()
    {
        $this->subject = new \Typo3\Issue78128\Domain\Model\TableB();
    }

    protected function tearDown()
    {
        parent::tearDown();
    }

    /**
     * @test
     */
    public function getC1ReturnsInitialValueForTableC()
    {
        $newObjectStorage = new \TYPO3\CMS\Extbase\Persistence\ObjectStorage();
        self::assertEquals(
            $newObjectStorage,
            $this->subject->getC1()
        );

    }

    /**
     * @test
     */
    public function setC1ForObjectStorageContainingTableCSetsC1()
    {
        $c1 = new \Typo3\Issue78128\Domain\Model\TableC();
        $objectStorageHoldingExactlyOneC1 = new \TYPO3\CMS\Extbase\Persistence\ObjectStorage();
        $objectStorageHoldingExactlyOneC1->attach($c1);
        $this->subject->setC1($objectStorageHoldingExactlyOneC1);

        self::assertAttributeEquals(
            $objectStorageHoldingExactlyOneC1,
            'c1',
            $this->subject
        );

    }

    /**
     * @test
     */
    public function addC1ToObjectStorageHoldingC1()
    {
        $c1 = new \Typo3\Issue78128\Domain\Model\TableC();
        $c1ObjectStorageMock = $this->getMock(\TYPO3\CMS\Extbase\Persistence\ObjectStorage::class, ['attach'], [], '', false);
        $c1ObjectStorageMock->expects(self::once())->method('attach')->with(self::equalTo($c1));
        $this->inject($this->subject, 'c1', $c1ObjectStorageMock);

        $this->subject->addC1($c1);
    }

    /**
     * @test
     */
    public function removeC1FromObjectStorageHoldingC1()
    {
        $c1 = new \Typo3\Issue78128\Domain\Model\TableC();
        $c1ObjectStorageMock = $this->getMock(\TYPO3\CMS\Extbase\Persistence\ObjectStorage::class, ['detach'], [], '', false);
        $c1ObjectStorageMock->expects(self::once())->method('detach')->with(self::equalTo($c1));
        $this->inject($this->subject, 'c1', $c1ObjectStorageMock);

        $this->subject->removeC1($c1);

    }

    /**
     * @test
     */
    public function getC2ReturnsInitialValueForTableC()
    {
        $newObjectStorage = new \TYPO3\CMS\Extbase\Persistence\ObjectStorage();
        self::assertEquals(
            $newObjectStorage,
            $this->subject->getC2()
        );

    }

    /**
     * @test
     */
    public function setC2ForObjectStorageContainingTableCSetsC2()
    {
        $c2 = new \Typo3\Issue78128\Domain\Model\TableC();
        $objectStorageHoldingExactlyOneC2 = new \TYPO3\CMS\Extbase\Persistence\ObjectStorage();
        $objectStorageHoldingExactlyOneC2->attach($c2);
        $this->subject->setC2($objectStorageHoldingExactlyOneC2);

        self::assertAttributeEquals(
            $objectStorageHoldingExactlyOneC2,
            'c2',
            $this->subject
        );

    }

    /**
     * @test
     */
    public function addC2ToObjectStorageHoldingC2()
    {
        $c2 = new \Typo3\Issue78128\Domain\Model\TableC();
        $c2ObjectStorageMock = $this->getMock(\TYPO3\CMS\Extbase\Persistence\ObjectStorage::class, ['attach'], [], '', false);
        $c2ObjectStorageMock->expects(self::once())->method('attach')->with(self::equalTo($c2));
        $this->inject($this->subject, 'c2', $c2ObjectStorageMock);

        $this->subject->addC2($c2);
    }

    /**
     * @test
     */
    public function removeC2FromObjectStorageHoldingC2()
    {
        $c2 = new \Typo3\Issue78128\Domain\Model\TableC();
        $c2ObjectStorageMock = $this->getMock(\TYPO3\CMS\Extbase\Persistence\ObjectStorage::class, ['detach'], [], '', false);
        $c2ObjectStorageMock->expects(self::once())->method('detach')->with(self::equalTo($c2));
        $this->inject($this->subject, 'c2', $c2ObjectStorageMock);

        $this->subject->removeC2($c2);

    }
}
